pub enum Mode {
Repl,
Script(Source),
Check(Source),
}Variants
Repl
Read input line by line from the user and compile/execute it. provide completion and print the value of the last expression as it executes. Ctrl-C cancel’s execution of the last expression and Ctrl-D exits the shell.
Script(Source)
Load compile and execute a file. Print the value of the last expression in the file to stdout. Ctrl-C exits the shell.
Check(Source)
Check that the specified file compiles but do not run it