Module lsp_backend

Module lsp_backend 

LSP backend that owns a graphix runtime with the stdlib loaded and exposes a synchronous interface for the LSP server.

Functions

run
Build a tokio runtime, stand up a graphix runtime with the in-process netidx and the full stdlib loaded, and run the LSP server until it shuts down.