pub struct ShellBuilder<X: GXExt> { /* private fields */ }Expand description
Builder for Shell.
Implementations
Sourceimpl<X: GXExt> ShellBuilder<X>
impl<X: GXExt> ShellBuilder<X>
Sourcepub fn publish_timeout(self, value: Duration) -> Self
pub fn publish_timeout(self, value: Duration) -> Self
drop subscribers if they don’t consume updates after this timeout
Sourcepub fn resolve_timeout(self, value: Duration) -> Self
pub fn resolve_timeout(self, value: Duration) -> Self
module resolution from netidx will fail if it can’t subscribe before this time elapses
Sourcepub fn module_resolvers(self, value: Vec<ModuleResolver>) -> Self
pub fn module_resolvers(self, value: Vec<ModuleResolver>) -> Self
define module resolvers to append to the default list
Sourcepub fn publisher(self, value: Publisher) -> Self
pub fn publisher(self, value: Publisher) -> Self
The netidx publisher to use. If you do not wish to use netidx you can use netidx::InternalOnly to create an internal netidx environment
Sourcepub fn subscriber(self, value: Subscriber) -> Self
pub fn subscriber(self, value: Subscriber) -> Self
The netidx subscriber to use. If you do not wish to use netidx you can use netidx::InternalOnly to create an internal netidx environment
Sourcepub fn enable_flags(self, value: BitFlags<CFlag>) -> Self
pub fn enable_flags(self, value: BitFlags<CFlag>) -> Self
Enable compiler flags, these will be ORed with the default set of flags for the mode.
Sourcepub fn disable_flags(self, value: BitFlags<CFlag>) -> Self
pub fn disable_flags(self, value: BitFlags<CFlag>) -> Self
Disable compiler flags, these will be subtracted from the final set. (default_flags | enable_flags) - disable_flags