ShellBuilder

Struct ShellBuilder 

pub struct ShellBuilder<X: GXExt> { /* private fields */ }
Builder for Shell.

Implementations

Source

impl<X: GXExt> ShellBuilder<X>

pub fn no_init(self, value: bool) -> Self

do not run the users init module

pub fn publish_timeout(self, value: Duration) -> Self

drop subscribers if they don’t consume updates after this timeout

pub fn resolve_timeout(self, value: Duration) -> Self

module resolution from netidx will fail if it can’t subscribe before this time elapses

pub fn module_resolvers(self, value: Vec<ModuleResolver>) -> Self

define module resolvers to append to the default list

pub fn mode(self, value: Mode) -> Self

set the shell’s mode

pub fn publisher(self, value: Publisher) -> Self

The netidx publisher to use. If you do not wish to use netidx you can use netidx::InternalOnly to create an internal netidx environment

pub fn subscriber(self, value: Subscriber) -> Self

The netidx subscriber to use. If you do not wish to use netidx you can use netidx::InternalOnly to create an internal netidx environment

pub fn enable_flags(self, value: BitFlags<CFlag>) -> Self

Enable compiler flags, these will be ORed with the default set of flags for the mode.

pub fn disable_flags(self, value: BitFlags<CFlag>) -> Self

Disable compiler flags, these will be subtracted from the final set. (default_flags | enable_flags) - disable_flags

pub fn build(self) -> Result<Shell<X>, ShellBuilderError>

Builds a new Shell.

Errors

If a required field has not been initialized.